library(tidyverse)
library(ggpattern)
library(ggstream)
library(ggsci)
library(scales)
library(ggrepel)
library(ggradar)

height <- 5
width <- height*1.5

c25 <- c(
  "dodgerblue2", "#E31A1C", # red
  "green4",
  "#6A3D9A", # purple
  "#FF7F00", # orange
  "black", "gold1",
  "skyblue2", "#FB9A99", # lt pink
  "palegreen2",
  "#CAB2D6", # lt purple
  "#FDBF6F", # lt orange
  "gray70", "khaki2",
  "maroon", "orchid1", "deeppink1", "blue1", "steelblue4",
  "darkturquoise", "green1", "yellow4", "yellow3",
  "darkorange4", "brown"
)

# Density plot 2D, two variables => counts
e.clean %>% 
   filter(Model > 2015) %>%
   ggplot(aes(x=Hwy, y=City)) + 
     geom_point(color="black", size=1, position='jitter') +
     geom_density_2d_filled(alpha=0.5) + 
     geom_density_2d(linewidth=0.25, colour='black') + 
     scale_x_continuous(labels=scales::comma) +
     labs(x = 'Highway Fuel Consumption\n(l/100km equivalent)', y = 'City Fuel Consumption\n(l/100km equivalent)', title='Density Plot - Canada Fuel Consumption Ratings - Battery Electric Vehicles', subtitle='Years 2015 to 2024') +
     theme(legend.position='none')
     
ggsave("fuel.density2d.png", height=height, width=width)
ggsave("fuel.density2d.pdf", height=height, width=width)

# Density Bin plot 2D, two variables => counts
e.clean %>% 
#   filter(Model > 2015) %>%
   ggplot(aes(x=Hwy, y=City)) + 
     geom_point(color="black", size=1, position='jitter') +
     geom_bin2d(alpha=0.5, bins=5) + 
     scale_x_continuous(labels=scales::comma) +
     labs(x = 'Highway Fuel Consumption\n(l/100km equivalent)', y = 'City Fuel Consumption\n(l/100km equivalent)', fill='Count', title='Density Plot - Canada Fuel Consumption Ratings - Battery Electric Vehicles', subtitle='Years 2012 to 2024') 
     
ggsave("fuel.bin2d.png", height=height, width=width)
ggsave("fuel.bin2d.pdf", height=height, width=width)

# Density Hex plot 2D, two variables => counts
e.clean %>% 
#   filter(Model > 2015) %>%
   ggplot(aes(x=Hwy, y=City)) + 
     geom_point(color="black", size=1, position='jitter') +
     geom_hex(alpha=0.5, bins=5) + 
     scale_fill_distiller(palette=4, direction=-1) +
     scale_x_continuous(labels=scales::comma) +
     labs(x = 'Highway Fuel Consumption\n(l/100km equivalent)', y = 'City Fuel Consumption\n(l/100km equivalent)', fill='Count', title='Density Plot - Canada Fuel Consumption Ratings - Battery Electric Vehicles', subtitle='Years 2012 to 2024') 
     
ggsave("fuel.hex2d.png", height=height, width=width)
ggsave("fuel.hex2d.pdf", height=height, width=width)

# Raster plot 2D, two variables => counts
e.clean %>% 
#   filter(Model > 2015) %>%
   ggplot(aes(x=Hwy, y=City)) + 
     geom_point(color="black", size=0.5, position='jitter') +
     geom_raster(aes(fill=Range), alpha=0.7, interpolate=TRUE) + 
     # geom_contour(aes(z=Range), linewidth=0.25, colour='black') + 
     scale_fill_distiller(palette=4, direction=-1) +
     scale_x_continuous(labels=scales::comma) +
     labs(x = 'Highway Fuel Consumption\n(l/100km equivalent)', y = 'City Fuel Consumption\n(l/100km equivalent)', fill='Range', title='Contour Plot - Canada Fuel Consumption Ratings - Battery Electric Vehicles', subtitle='Years 2012 to 2024') 
     
ggsave("fuel.raster.png", height=height, width=width)
ggsave("fuel.raster.pdf", height=height, width=width)

# Raster plot 2D, two variables => counts, with RUG
e.clean %>% 
#   filter(Model > 2015) %>%
   ggplot(aes(x=Hwy, y=City)) + 
     geom_point(color="black", size=0.5, position='jitter') +
     geom_rug(position='jitter') + 
     geom_raster(aes(fill=Range), alpha=0.7, interpolate=TRUE) + 
     # geom_contour(aes(z=Range), linewidth=0.25, colour='black') + 
     scale_fill_distiller(palette=4, direction=-1) +
     scale_x_continuous(labels=scales::comma) +
     labs(x = 'Highway Fuel Consumption\n(l/100km equivalent)', y = 'City Fuel Consumption\n(l/100km equivalent)', fill='Range', title='Contour Plot - Canada Fuel Consumption Ratings - Battery Electric Vehicles', subtitle='Years 2012 to 2024') 
     
ggsave("fuel.raster.rug.png", height=height, width=width)
ggsave("fuel.raster.rug.pdf", height=height, width=width)

# Density plot, one variable => counts
mean_v <- e.clean %>% 
   summarize(mean_v = mean(Range), median_v = median(Range), lower95=quantile(Range, .025), upper95=quantile(Range, .975), maxdensity = max(density(Range)$y))

e.clean %>% 
   ggplot(aes(Range)) + 
     geom_density(kernel='gaussian', fill='lightblue') + 
     scale_x_continuous(labels=scales::comma) +
     scale_y_continuous(labels=scales::comma) + 
     # scale_fill_brewer(palette="Dark2") +
     labs(x = 'Range (km)', y = 'Proportion of Vehicles', title='Density Plot - Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2012 to 2024', caption='Lower and Upper 95 percentile, median and mean') +
     # coord_cartesian(xlim=c(0, 100000)) +
     geom_vline(data=mean_v, aes(xintercept=mean_v), linetype='dashed') +
     geom_vline(data=mean_v, aes(xintercept=median_v), linetype='dotdash') +
     geom_vline(data=mean_v, aes(xintercept=lower95), linetype='dotted') +
     geom_vline(data=mean_v, aes(xintercept=upper95), linetype='dotted') + 
     annotate('text', label = paste(' L95=\n ', round(mean_v$lower95), sep=''), x = mean_v$lower95, y = mean_v$maxdensity/2, size=3.5, hjust=0) +
     annotate('text', label = paste(' Med=\n ', round(mean_v$median_v), sep=''), x = mean_v$median_v, y = mean_v$maxdensity*3/4, size=3.5, hjust=0) +
     annotate('text', label = paste(' Mean=\n ', round(mean_v$mean_v), sep=''), x = mean_v$mean_v, y = mean_v$maxdensity*5/8, size=3.5, hjust=0) + 
     annotate('text', label = paste(' U95=\n ', round(mean_v$upper95), sep=''), x = mean_v$upper95, y = mean_v$maxdensity/2, size=3.5, hjust=0)
 
ggsave("fuel.density.png", height=height, width=width)
ggsave("fuel.density.pdf", height=height, width=width)

# Histogram plot, one variable => counts
# Density plot, one variable => counts
mean_v <- e.clean %>% 
   summarize(mean_v = mean(Range), median_v = median(Range), lower95=quantile(Range, .025), upper95=quantile(Range, .975), maxdensity = max(density(Range)$y))

e.clean %>% 
   ggplot(aes(Range)) + 
     geom_histogram(aes(y=..density..), bins=50, fill='white', color='black', alpha=0.5) +
     geom_density(kernel='gaussian', alpha=0.25, fill='lightblue') + 
     scale_x_continuous(labels=scales::comma) +
     scale_y_continuous(labels=scales::comma) + 
     # scale_fill_brewer(palette="Dark2") +
     labs(x = 'Range (km)', y = 'Proportion of Vehicles', title='Density Plot - Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2012 to 2024', caption='Lower and Upper 95 percentile, median and mean') +
     # coord_cartesian(xlim=c(0, 100000)) +
     geom_vline(data=mean_v, aes(xintercept=mean_v), linetype='dashed') +
     geom_vline(data=mean_v, aes(xintercept=median_v), linetype='dotdash') +
     geom_vline(data=mean_v, aes(xintercept=lower95), linetype='dotted') +
     geom_vline(data=mean_v, aes(xintercept=upper95), linetype='dotted') + 
     annotate('text', label = paste(' L95=\n ', round(mean_v$lower95), sep=''), x = mean_v$lower95, y = mean_v$maxdensity/2, size=3.5, hjust=0) +
     annotate('text', label = paste(' Med=\n ', round(mean_v$median_v), sep=''), x = mean_v$median_v, y = mean_v$maxdensity*3/4, size=3.5, hjust=0) +
     annotate('text', label = paste(' Mean=\n ', round(mean_v$mean_v), sep=''), x = mean_v$mean_v, y = mean_v$maxdensity*5/8, size=3.5, hjust=0) + 
     annotate('text', label = paste(' U95=\n ', round(mean_v$upper95), sep=''), x = mean_v$upper95, y = mean_v$maxdensity/2, size=3.5, hjust=0)
 
ggsave("fuel.histogram.png", height=height, width=width)
ggsave("fuel.histogram.pdf", height=height, width=width)

# Area plot, two variables in one series
e.clean %>% 
   group_by(Year) %>%
   summarize(meanRange = mean(Range)) %>%
   ungroup() %>%
   ggplot(aes(Year, meanRange)) + 
     geom_area(fill='purple') +
     geom_text(aes(label=round(meanRange)), size=5, position='jitter') +
     scale_y_continuous(labels=scales::comma) +
     labs(x = 'Year', y = 'Mean Range (km)', title='Canadian Fuel Consumption Data - Electric Vehicle Range by Year', subtitle='Years 2012-2024')
ggsave("fuel.areaOneSeries.png", height=height, width=width)
ggsave("fuel.areaOneSeries.pdf", height=height, width=width)


# Column Plot
e.clean %>% 
   group_by(Year) %>%
   summarize(meanCity = mean(City), meanHwy = mean(Hwy)) %>%
   ungroup() %>%
   pivot_longer(cols=c('meanCity', 'meanHwy'), names_to='metric', values_to='consumption') %>%
   ggplot(aes(Year, consumption, fill=metric)) +
      geom_col(position='dodge') +
      scale_fill_brewer(palette="Paired") +
      scale_fill_discrete(labels=c("City", "Highway")) + 
      scale_y_continuous(labels=scales::comma) + 
      labs(x = 'Year', y='Mean Fuel Consumption\n(l/100km equivalent)', fill='', title='Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2012 to 2024', )
ggsave("fuel.columns.png", height=height, width=width)
ggsave("fuel.columns.pdf", height=height, width=width)


# Column Plot with Patterns
e.clean %>% 
   group_by(Year) %>%
   summarize(meanCity = mean(City), meanHwy = mean(Hwy)) %>%
   ungroup() %>%
   pivot_longer(cols=c('meanCity', 'meanHwy'), names_to='metric', values_to='consumption') %>%
   ggplot(aes(Year, consumption)) +
      geom_col_pattern( aes(pattern_type=metric, pattern_angle=metric),
						position='dodge',
						pattern_fill='white', 
						pattern='polygon_tiling',
						pattern_scale=0.5,
						pattern_key_scale_factor=0.4) +
      scale_fill_brewer(palette="Paired") +
      scale_pattern_type_manual(values = c('hexagonal', 'rhombille', 'pythagorean', 'truncated_square', 'rhombitrihexagonal', 'truncated_trihexagonal'), labels=c("City", "Highway")) + 
      scale_y_continuous(labels=scales::comma) + 
      labs(x = 'Year', y='Mean Fuel Consumption\n(l/100km equivalent)', pattern_type='', title='Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2012 to 2024', ) +
      guides(pattern_angle=FALSE, pattern_type=guide_legend(nrow=1)) + 
      theme(legend.key.size=unit(1.5, 'cm'), legend.position='bottom')
ggsave("fuel.columnsPatterns.png", height=height, width=width)
ggsave("fuel.columnsPatterns.pdf", height=height, width=width)


# Box Plot
e.clean %>% 
   pivot_longer(cols=c('City', 'Hwy'), names_to='metric', values_to='consumption') %>%
   ggplot(aes(x=as.factor(Year), y=consumption, fill=metric)) +
      geom_boxplot() +
	  stat_summary(
		aes(label = round(stat(y), 1)),
		geom = "text", 
		size=2,
		fun.y = function(y) { o <- boxplot.stats(y)$out; if(length(o) == 0) NA else o }) + 
        scale_fill_brewer(palette="Paired") +
      # scale_fill_discrete(labels=c("Advance Contract Award Notice", "Open Bidding", "Selective Tendering", "Traditional", "Non-Competitive", "Unknown")) + 
     labs(x = 'Year', y='Mean Fuel Consumption\n(l/100km equivalent)', fill='', title='Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2012 to 2024', ) +
     scale_y_continuous(labels=scales::comma) +
     theme(legend.key.size=unit(1, 'cm'), legend.position='top')
ggsave("fuel.box.png", height=height, width=width)
ggsave("fuel.box.pdf", height=height, width=width)

# Violin Plot
e.clean %>% 
   ggplot(aes(x=as.factor(Year), y=Comb)) +
     geom_violin(fill='lightblue') +
     scale_fill_brewer(palette="Paired") +
     labs(x = 'Year', y='Mean Fuel Consumption\n(l/100km equivalent)', fill='', title='Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2012 to 2024', ) +
     scale_y_continuous(labels=scales::comma) +
     geom_jitter(width=0.15, color='black', size=1, fill=NA, alpha=0.5) + 
     theme(legend.position='top', 
			legend.background=element_blank(), 
			legend.box.background=element_rect(color='black', fill='lightgrey'),
			legend.key.size=unit(1, 'cm')) 
ggsave("fuel.violin.png", height=height, width=width)
ggsave("fuel.violin.pdf", height=height, width=width)

# Dot Plot
e.clean %>% 
   ggplot(aes(x=as.factor(Year), y=Comb)) +
     geom_dotplot(binaxis='y', 
					stackdir='center', 
					stackratio=0.5,
					binpositions='all',
					dotsize=0.5, color='black', fill='orange') +
     scale_fill_brewer(palette="Paired") +
     labs(x = 'Year', y='Mean Fuel Consumption\n(l/100km equivalent)', fill='', title='Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2012 to 2024', ) +
     scale_y_continuous(labels=scales::comma) +
     theme(legend.position='top', 
			legend.background=element_blank(), 
			legend.box.background=element_rect(color='black', fill='lightgrey'),
			legend.key.size=unit(1, 'cm')) 
ggsave("fuel.dotplot.png", height=height, width=width)
ggsave("fuel.dotplot.pdf", height=height, width=width)

# Dot Plot
e.clean %>% 
   filter(Year > 2019) %>%
   ggplot(aes(x=as.factor(Year), y=Comb, fill=)) +
     geom_dotplot(binaxis='y', 
					stackdir='center', 
					stackratio=0.5,
					binpositions='all',
					dotsize=0.5, color='black', fill='orange') +
     scale_fill_brewer(palette="Paired") +
	 geom_violin(color='black', fill=NA) + 
	 stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), size=1, color='blue', geom="pointrange") +
     labs(x = 'Year', y='Mean Fuel Consumption\n(l/100km equivalent)', fill='', title='Canadian Fuel Consumption Data - Electric Vehicle Range', subtitle='Years 2020 to 2024', ) +
     # scale_x_discrete(title='Year') + 
     scale_y_continuous(labels=scales::comma) +
     theme(legend.position='none')
ggsave("fuel.dotplotjviolinsummary.png", height=height, width=width)
ggsave("fuel.dotplotjviolinsummary.pdf", height=height, width=width)


# Counts
e.clean %>% 
   ggplot(aes(as.factor(Year), as.factor(Category))) +
      geom_count(color='darkolivegreen4')+
      scale_size_area(max_size=10, n.breaks=6) + 
      scale_color_brewer(palette="Paired") +
	  scale_y_discrete(labels=c('Compact', 'Large', 'Mid-Size', 'Pickup truck', 'Subcompact', 'Two-seater', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
	  guides(color=FALSE) +
     labs(x = 'Year', y='Category', fill='', title='Canadian Fuel Consumption Data - Electric Vehicle Models by Category', subtitle='Years 2012 to 2024', ) +
     theme(		legend.background=element_blank(), 
				legend.box.background=element_rect(color='black', fill=NA),
				legend.key.size=unit(1, 'cm'))

ggsave("fuel.count.png", height=height, width=width)
ggsave("fuel.count.pdf", height=height, width=width)

# Jitter over Discrete
e.clean %>% 
   ggplot(aes(x=as.factor(Year), y=as.factor(Category), color=as.factor(Year))) +
      geom_jitter(width=0.2, height=0.2) +
      # scale_size_area(max_size=10, n.breaks=6) + 
      # scale_color_brewer(palette="Paired") +
      scale_color_manual(values=c25) +
	  scale_y_discrete(labels=c('Compact', 'Large', 'Mid-Size', 'Pickup truck', 'Subcompact', 'Two-seater', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
	  guides(color=FALSE) +
     labs(x = 'Year', y='Category', fill='Make', title='Canadian Fuel Consumption Data - Electric Vehicle Models by Category', subtitle='Years 2012 to 2024', ) +
     theme(		legend.background=element_blank(), 
				legend.box.background=element_rect(color='black', fill=NA),
				legend.key.size=unit(1, 'cm'))

ggsave("fuel.jitterdiscrete.png", height=height, width=width)
ggsave("fuel.jitterdiscrete.pdf", height=height, width=width)

# Counts
# Jitter over Discrete
e.clean %>% 
   group_by(Year, Category) %>%
   summarize(totalcount=n(), meanRange=mean(Range)) %>%
   ungroup () %>%
   ggplot(aes(x=as.factor(Year), y=meanRange, size=totalcount, color=Category)) +
      geom_point(alpha=0.8) +
      # scale_size_area(max_size=10, n.breaks=6) + 
      # scale_color_brewer(palette="Paired") +
      scale_size_continuous(range=c(0, 20)) +
      # scale_color_manual(values=c25) +
      scale_color_tron() + 
      scale_y_continuous(labels=scales::comma) + 
	  scale_color_discrete(labels=c('Compact', 'Large', 'Mid-Size', 'Pickup truck', 'Subcompact', 'Two-seater', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
	  # guides(color=FALSE) +
     labs(x = 'Year', y='Range', fill='Make', size='Number of Models', title='Canadian Fuel Consumption Data - Electric Vehicle Range by Year and Category', subtitle='Years 2012 to 2024', ) +
	  guides(color=guide_legend(position='bottom'), size=guide_legend(position='right')) +
     theme(		legend.background=element_blank(), 
				legend.box.background=element_rect(color='black', fill=NA),
				legend.key.size=unit(1, 'cm')) 

ggsave("fuel.pointsSize.png", height=height*1.5, width=width*1.5)
ggsave("fuel.pointsSize.pdf", height=height*1.5, width=width*1.5)

# Lines and Points
e.clean %>% 
   filter(Year >= 2022 & Year <= 2023) %>%
   filter(Comb <= 4) %>%
   filter(Category != 'PL') %>%
   filter(Category != 'T') %>%
   ggplot(aes(Comb, Range, color=Category, shape=Category, linetype=Category)) +
	  geom_line(size=1) + 
	  geom_point(size=4) + 
	  scale_color_manual(values=c25, labels=c('Compact', 'Large', 'Mid-Size', 'Subcompact', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
	  scale_linetype(labels=c('Compact', 'Large', 'Mid-Size', 'Subcompact', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
	  scale_shape(labels=c('Compact', 'Large', 'Mid-Size', 'Subcompact', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
      scale_y_continuous(labels=scales::comma) + 
	  # scale_x_date(date_breaks = "months" , date_labels = "%b-%y", guide = guide_axis(n.dodge=2)) +
     labs(x = 'Combined Fuel Consumption\n(l/100km equivalent)', y='Range', title='Canadian Fuel Consumption Data - Electric Vehicle Range by Consumption', subtitle='Years 2022 to 2023', ) +
     theme(legend.key.size=unit(1, 'cm'), legend.position='bottom')

ggsave("fuel.linesPoints.png", height=height, width=width)
ggsave("fuel.linesPoints.pdf", height=height, width=width)


# Steps
e.clean %>% 
   filter(Year >= 2022 & Year <= 2023) %>%
   filter(Comb <= 4) %>%
   filter(Category != 'PL') %>%
   filter(Category != 'T') %>%
   ggplot(aes(Comb, Range, color=Category, linetype=Category)) +
	  geom_step(size=1) + 
	  scale_color_manual(values=c25, labels=c('Compact', 'Large', 'Mid-Size', 'Subcompact', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
	  scale_linetype(labels=c('Compact', 'Large', 'Mid-Size', 'Subcompact', 'SUV (standard)', 'SUV (small)', 'Station Wagon (small)')) + 
      scale_y_continuous(labels=scales::comma) + 
	  # scale_x_date(date_breaks = "months" , date_labels = "%b-%y", guide = guide_axis(n.dodge=2)) +
     labs(x = 'Combined Fuel Consumption\n(l/100km equivalent)', y='Range', title='Canadian Fuel Consumption Data - Electric Vehicle Range by Fuel Consumption', subtitle='Years 2022 to 2023', ) +
     theme(legend.key.size=unit(1.5, 'cm'))

ggsave("fuel.steps.png", height=height, width=width)
ggsave("fuel.steps.pdf", height=height, width=width)

# Pie
e.clean %>% 
   filter(Year==2023) %>%
   group_by(Make) %>%
   summarize(totalcount = n()) %>%
   filter(totalcount >= 5) %>%
   ungroup() %>%
   ggplot(aes(x='', y=totalcount, fill=Make)) +
	  geom_bar(stat='identity', color='black', size=0.25, width=1) + 
	  coord_polar('y', direction=-1, start=0) +
	  geom_text(aes(label=ifelse(totalcount >= 5, totalcount, '')), color='lightgrey', position = position_stack(vjust=0.5)) +
      scale_y_continuous(labels=NULL) + 
      scale_color_brewer(palette="Paired") +
      labs(x = '', y = '',  fill='Make', title='Canadian Fuel Consumption Data - Electric Vehicle Offerings by Make', subtitle='2023, Makes with more than 5 models') +
      theme_void() +
      theme(legend.key.size=unit(1, 'cm'))

ggsave("fuel.pie.png", height=width*1.5, width=height*1.5)
ggsave("fuel.pie.pdf", height=width*1.5, width=height*1.5)

hsize <- 2
# Donut
e.clean %>% 
   filter(Year==2023) %>%
   group_by(Make) %>%
   summarize(totalcount = n()) %>%
   filter(totalcount >= 5) %>%
   ungroup() %>%
   ggplot(aes(x=hsize, y=totalcount, fill=Make)) +
	  geom_col() + 
	  coord_polar('y', direction=-1, start=0) +
	  xlim(c(0.2, hsize+0.5)) + 
	  geom_text(aes(label=ifelse(totalcount > 5, totalcount, '')), color='white', position = position_stack(vjust=0.5)) +
      scale_color_brewer(palette="Paired") +
      labs(x = '', y = '',  fill='Make', title='Canadian Fuel Consumption Data - Electric Vehicle Offerings by Make', subtitle='2023, Makes with more than 5 models') +
      theme_void() +
      theme(legend.key.size=unit(1, 'cm'))

ggsave("fuel.donut.png", height=width*1.5, width=height*1.5)
ggsave("fuel.donut.pdf", height=width*1.5, width=height*1.5)


# Radar
e.clean %>% 
   filter(Year == 2023) %>%
   group_by(Make) %>%
   summarize(meanCity = 1/mean(City), meanHwy = 1/mean(Hwy), meanRange = mean(Range)/100, nModels = n()) %>%
   filter(nModels >= 5) %>%
   ungroup() %>%
   select(-nModels) %>%
   mutate_at(vars(-Make), rescale) %>%
   ggradar(axis.labels=c('City', 'Highway', 'Range (100km)'), values.radar='', group.line.width=0.75, group.point.size=3) +
      scale_color_ucscgb() +
      labs(x = '', y = '',  fill='Make', title='Canadian Fuel Consumption Data', subtitle='2023, Makes with more than 5 models')
      
ggsave("fuel.radar.png", height=width*1.5, width=width*1.5)
ggsave("fuel.radar.pdf", height=width*1.5, width=width*1.5)


# Lines with Multiple Axes
e.clean %>% 
   group_by(Year) %>%
   summarize(meanCity = mean(City), meanHwy = mean(Hwy), meanRange = mean(Range)) %>%
   ungroup() %>%
   mutate(meanRange2 = meanRange/100) %>%
#   replace_na(list(Atlantic2=0)) %>%
   ggplot(aes(x=Year)) +
	  scale_color_manual(name='Region', values=c('Mean City' = 'red', 'Mean Highway' = 'blue', 'Mean Range' = 'orange')) +
	  geom_line(aes(y=meanCity, color='Mean City'), size=1) + 
	  geom_line(aes(y=meanHwy, color='Mean Highway'), size=1) +
	  geom_line(aes(y=meanRange2, color='Mean Range'), size=1) +
      scale_y_continuous(labels=scales::comma, name="Fuel Consumption\n(l/100km equivalent)", sec.axis=sec_axis(~ .*100, labels=scales::comma, name="Mean Range (km)")) + 
	  # scale_x_date(date_breaks = "years" , date_labels = "%y") +
	  scale_x_continuous(breaks=seq(from=2012, to=2024, by=1)) + 
      labs(x = 'Year', color='', y = 'Mean Fuel Consumption\n(l/100km equivalent)', title='Canadian Fuel Consumption Data', subtitle='2012 to 2024') +
      theme(legend.key.size=unit(1.5, 'cm'), axis.text.x = element_text(angle=45, hjust=1))

ggsave("fuel.linesTwoScales.png", height=height, width=width)
ggsave("fuel.linesTwoScales.pdf", height=height, width=width)


# Lines with Smooth
e.clean %>% 
   ggplot(aes(Year, Range)) +
	  geom_point() +
	  geom_smooth() +
	  # guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  # scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=2)) +
      labs(x = 'Year', color='', y = 'Mean Range (km)', title='Canadian Fuel Consumption Data', subtitle='2012 to 2024')

ggsave("fuel.linesSmooth.png", height=height, width=width)
ggsave("fuel.linesSmooth.pdf", height=height, width=width)

# Lines with Smooth and Point Range
e.clean %>% 
   ggplot(aes(Year, Range)) +
	  geom_point() +
	  geom_smooth() +
	  stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), color='red', geom="pointrange") +
	  # guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  # scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=2)) +
      labs(x = 'Year', color='', y = 'Mean Range (km)', title='Canadian Fuel Consumption Data', subtitle='2012 to 2024')

ggsave("fuel.linesSmoothPointRange.png", height=height, width=width)
ggsave("fuel.linesSmoothPointRange.pdf", height=height, width=width)

# Lines with Smooth and ErrorBar
e.clean %>% 
   ggplot(aes(Year, Range)) +
	  geom_point() +
	  geom_smooth() +
	  stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), color='red', geom="errorbar") +
	  # guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  # scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=2)) +
      labs(x = 'Year', color='', y = 'Mean Range (km)', title='Canadian Fuel Consumption Data', subtitle='2012 to 2024')

ggsave("fuel.linesSmoothErrorBar.png", height=height, width=width)
ggsave("fuel.linesSmoothErrorBar.pdf", height=height, width=width)


# Lines with Smooth and CrossBar
e.clean %>% 
   ggplot(aes(Year, Range)) +
	  geom_point() +
	  geom_smooth() +
	  stat_summary(fun.data=mean_sdl, fun.args=list(mult=1), color='red', geom="crossbar", width=0.4) +
	  # guides(color=FALSE) + 
      scale_y_continuous(labels=scales::comma) + 
	  # scale_x_date(date_breaks = "months" , minor_breaks=NULL, date_labels = "%b-%y", guide = guide_axis(n.dodge=2)) +
      labs(x = 'Year', color='', y = 'Mean Range (km)', title='Canadian Fuel Consumption Data', subtitle='2012 to 2024')

ggsave("fuel.linesSmoothCrossBar.png", height=height, width=width)
ggsave("fuel.linesSmoothCrossBar.pdf", height=height, width=width)


